@@ -98,23 +98,29 @@ class FireStore(object):
 	# system functions.
 	def list(self, reference):
 		doc = self.__get_doc__(reference)
+		error = None
 		try:
 			doc = doc.get()
 			success = True
-		except: success = False
+		except Exception as e: 
+			error = e
+			success = False
 		if not success:
-			return dev0s.response.error(f"Failed to load document [{reference}].")
+			return dev0s.response.error(f"Failed to load document [{reference}]: {error}.")
 		if not isinstance(doc, list):
 			return dev0s.response.error(f"Reference [{reference}] leads to a document, not a collection.")
 		return dev0s.response.success(f"Successfully listed the content of collection [{reference}].", {"collection":doc})
 	def load(self, reference):
 		doc = self.__get_doc__(reference)
+		error = None
 		try:
 			doc = doc.get()
 			success = True
-		except: success = False
+		except Exception as e: 
+			error = e
+			success = False
 		if not success:
-			return dev0s.response.error(f"Failed to load document [{reference}].")
+			return dev0s.response.error(f"Failed to load document [{reference}]: {error}.")
 		if isinstance(doc, list):
 			return dev0s.response.error(f"Reference [{reference}] leads to a collection, not a document.")
 		if not doc.exists:
@@ -124,12 +130,15 @@ class FireStore(object):
 			return dev0s.response.success(f"Successfully loaded document [{reference}].", {"data":data})
 	def load_collection(self, reference):
 		doc = self.__get_doc__(reference)
+		error = None
 		try:
 			doc = doc.get()
 			success = True
-		except: success = False
+		except Exception as e: 
+			error = e
+			success = False
 		if not success:
-			return dev0s.response.error(f"Failed to load document [{reference}].")
+			return dev0s.response.error(f"Failed to load document [{reference}]: {error}.")
 		if isinstance(doc, dict):
 			return dev0s.response.error(f"Reference [{reference}] leads to a document, not a collection.")
 		data = []
@@ -139,24 +148,30 @@ class FireStore(object):
 		return dev0s.response.success(f"Successfully loaded the document names of collection [{reference}].", {"collection":data, "documents":doc})
 	def save(self, reference, data):
 		doc = self.__get_doc__(reference)
+		error = None
 		try:
 			doc.set(data)
 			success = True
-		except: success = False
+		except Exception as e: 
+			error = e
+			success = False
 		if success:
 			return dev0s.response.success(f"Successfully saved document [{reference}].")
 		else:
-			return dev0s.response.error(f"Failed to save document [{reference}].")
+			return dev0s.response.error(f"Failed to save document [{reference}]: {error}.")
 	def delete(self, reference):
 		doc = self.__get_doc__(reference)
+		error = None
 		try:
 			doc.delete()
 			success = True
-		except: success = False
+		except Exception as e: 
+			error = e
+			success = False
 		if success:
 			return dev0s.response.success(f"Successfully deleted document [{reference}].")
 		else:
-			return dev0s.response.error(f"Failed to delete document [{reference}].")
+			return dev0s.response.error(f"Failed to delete document [{reference}]: {error}.")
 	# system functions.
 	def __get_doc__(self, reference):
 		reference = reference.replace("//", "/")
